Installing Mox
=============

Download the latest version of Mox. Expand the tarball, and run:

.. highlight:: bash

::

    $ python setup.py install

To run Mox's own tests, run:

.. highlight:: bash

::

    $ python mox_test.py
